@@ -191,8 +191,35 @@ class Node:
 
         return self.name
 
-    def rename(self, new_name):
-        self.name = new_name
+    def rename(self, new_name, old_name=""):
+        if old_name == "":
+            old_name = self.name
+            self.name = new_name
+
+        for param in self.parameters_changes:
+            expr = param.get_expression()
+            if expr is not None:
+                expr.rename_node_inside(new_name, old_name)
+
+        for param in self.parameters:
+            expr = param.get_expression()
+            if expr is not None:
+                expr.rename_node_inside(new_name, old_name)
+
+        for var in self.variables:
+            var.rename_inside_expressions(new_name, old_name)
+
+        for constraints in self.constraints:
+            constraints.rename_inside_expressions(new_name, old_name)
+
+        for obj in self.objectives:
+            obj.rename_inside_expressions(new_name, old_name)
+
+        for subnode in self.get_sub_nodes():
+            subnode.rename(new_name, old_name)
+
+        for subedge in self.get_sub_hyperedges():
+            subedge.rename(new_name, old_name)
 
     def get_constraints(self):
 
