@@ -11,7 +11,7 @@ from .compiler.classes import Parameter, Expression, Node, Hyperedge, Time, \
 from .compiler.utils import error_, move_to_directory
 from .solver_api import cplex_solver, gurobi_solver, clp_solver, dsp_solver, \
     xpress_solver, highs_solver, cbc_solver
-from .output import generate_json
+from .output import generate_json, generate_list_values_tuple
 
 from enum import Enum
 import os
@@ -338,7 +338,7 @@ class GbomlGraph:
         """
         return self.__solve(clp_solver)
 
-    def solve_cbc(self, opt_file= None, opt_dict= None):
+    def solve_cbc(self, opt_file=None, opt_dict=None):
         """
         bound method solving the flattened optimization problem with Cbc
 
@@ -404,6 +404,23 @@ class GbomlGraph:
 
         return self.__solve(dsp_solver_function)
 
+    def turn_solution_to_list(self, solution, constraints_info=None):
+        """
+            bound method converting the flat solution to a list of <name, value> tuples
+
+            Args:
+                solution (ndarray) : flattened solution
+                constraints_info (dict) : dict of additional information
+                                         concerning constraints
+
+            Returns:
+                output_list (list): list of <name, value> tuples
+        """
+        list_names, list_values = generate_list_values_tuple(self.program, solution, self.vector_c,
+                                                             self.indep_term_c, constraints_info=constraints_info)
+        output_list = list(zip(list_names, list_values))
+        return output_list
+
     def turn_solution_to_dictionary(self, solver_data, status, solution,
                                     objective, constraint_info=None,
                                     variables_info=None):
@@ -480,26 +497,37 @@ class GbomlGraph:
         Returns:
 
         """
-        parameter = None
-        if isinstance(value, Parameter):
-            parameter = value
-        elif isinstance(value, str):
-            parameter = Parameter(identifier, value)
-        elif isinstance(value, float) or isinstance(value, int):
+        parameter = self.create_parameter(identifier, value)
+        self.global_parameters.append(parameter)
+
+    @staticmethod
+    def modify_parameter_value(parameter, value):
+        """
+        Modify the value of parameter
+
+        Args:
+           parameter (Parameter) : parameter to modify
+           value (int|float|list<float/int>) : value associated to the parameter
+        Returns:
+
+        """
+        if isinstance(value, float) or isinstance(value, int):
             expr = Expression('literal', value)
-            parameter = Parameter(identifier, expr)
+            parameter.expression = expr
+            parameter.type = "expression"
+            parameter.vector = None
         elif isinstance(value, list):
             expression_values = []
             expr = None
+            parameter.expression = expr
             for val in value:
                 expr = Expression('literal', val)
                 expression_values.append(expr)
-            parameter = Parameter(identifier, None)
+            parameter.type = "table"
             parameter.set_vector(expression_values)
         else:
             error_("Unaccepted type value for global parameter "
                    + str(type(value)))
-        self.global_parameters.append(parameter)
 
     @staticmethod
     def import_all_nodes_and_edges(filename):
@@ -629,13 +657,32 @@ class GbomlGraph:
 
         Args:
            parameter_name (str) : parameter name
-           value (float/int) : value of parameter
+           value (float/int/list<int/float>) : value of parameter
 
         Returns:
             param (Parameter): parameter created
 
         """
-        return Parameter(parameter_name, Expression("literal", value))
+        parameter = None
+        if isinstance(value, Parameter):
+            parameter = value
+        elif isinstance(value, str):
+            parameter = Parameter(parameter_name, value)
+        elif isinstance(value, float) or isinstance(value, int):
+            expr = Expression('literal', value)
+            parameter = Parameter(parameter_name, expr)
+        elif isinstance(value, list):
+            expression_values = []
+            expr = None
+            for val in value:
+                expr = Expression('literal', val)
+                expression_values.append(expr)
+            parameter = Parameter(parameter_name, None)
+            parameter.set_vector(expression_values)
+        else:
+            error_("Unaccepted type value for global parameter "
+                   + str(type(value)))
+        return parameter
 
     @staticmethod
     def rename(node_or_hyperedge, new_name):
